"use strict";

var atob = require('atob');

var aesjs = require('aes-js');

var pbkdf2 = require('pbkdf2');

var JSONCheck = require('../lib/JSONCheck.js');

module.exports = function (cipherText, password) {
  var derivedKey = pbkdf2.pbkdf2Sync(password, 'salt', 1, 256 / 8, 'sha512');
  var splitCipherText = cipherText.split(':');
  var ivInHex = splitCipherText[0];
  var encryptedHex = splitCipherText[1];
  var iv = aesjs.utils.hex.toBytes(ivInHex);
  var encryptedBytes = aesjs.utils.hex.toBytes(encryptedHex);
  var aesCBC = new aesjs.ModeOfOperation.cbc(derivedKey, iv);
  var decryptedBytes = aesCBC.decrypt(encryptedBytes);
  var decryptedTextInBase64 = aesjs.utils.utf8.fromBytes(decryptedBytes);
  decryptedTextInBase64 = decryptedTextInBase64.replace(/=/g, '');
  var decryptedText = decodeURIComponent(escape(atob(decryptedTextInBase64)));

  if (JSONCheck.IsJson(decryptedText)) {
    return JSON.parse(decryptedText);
  }

  return decryptedText;
};